@@ -14,6 +14,7 @@ from .sentiment_analysis import SentimentAnalysis
 from .toucan import Toucan
 from .pandas_extra import PandasExtra
 
+__version__ = "0.0.17"
 
 darkknight = DarkKnight
 ftp = Ftp
@@ -22,7 +23,7 @@ ftps = Ftps
 geoLocator = GeoLocator
 google_spreadsheet = GoogleSpreadsheet
 healthCheck = HealthCheck
-mail = Email
+email = Email
 mongo = Mongo
 pdf = Pdf
 plot = Plot
